@@ -7,7 +7,7 @@ from typing import List, Dict, Text, Union, Any
 
 from loguru import logger
 
-from rrtv_httprunner import exceptions
+from rrtv_httprunner import exceptions, globalvar
 from rrtv_httprunner.loader import load_project_meta, convert_relative_project_root_dir
 from rrtv_httprunner.parser import parse_data
 from rrtv_httprunner.utils import sort_dict_by_custom_order
@@ -271,7 +271,14 @@ def ensure_cli_args(args: List) -> List:
         )
         args.pop(args.index("--save-tests"))
         _generate_conftest_for_summary(args)
-
+    for arg in args:
+        if "--toexcel" in arg:
+            index = args.index(arg)
+            globalvar.set_value("toexcel", str(args[index]).split("=")[1])
+            args.pop(index)
+            path = globalvar.get_value("toexcel")
+            if os.path.exists(path):
+                os.remove(path)
     return args
 
 
