@@ -4,6 +4,7 @@ import os
 import re
 from typing import Any, Set, Text, Callable, List, Dict
 
+import demjson
 from loguru import logger
 from sentry_sdk import capture_exception
 
@@ -397,13 +398,10 @@ def parse_string(
                     suffix2 = suffix_re[0]
                 else:
                     suffix = suffix_re[0]
-                if isinstance(var_value, Text) or isinstance(var_value, int):
-                    var_value = var_value
-                else:
-                    if var_value is not None:
-                        var_value = var_value[suffix]
-                    else:
-                        return var_value
+                if var_value is None:
+                    return var_value
+                if not isinstance(var_value, Text) and not isinstance(var_value, int):
+                    var_value = var_value[suffix]
                 full_string = remove_bracket_first(raw_string)
                 raw_string = full_string
 
