@@ -1,4 +1,5 @@
 # @author: chenfanghang
+import json
 from typing import Union, Text, Dict
 
 import redis
@@ -30,8 +31,11 @@ class RedisHandler:
         if res:
             return res.decode()  # 从redis里面拿到的是bytes类型的数据，需要转换一下
 
-    def str_set(self, k, v, time=None):  # time默认失效时间
-        self.r.set(k, v, time)
+    def str_set(self, k, v, ex=None):  # time默认失效时间
+        if isinstance(v, Dict):
+            self.r.set(k, json.dumps(v), ex=ex)
+        else:
+            self.r.set(k, v, ex=ex)
 
     def delete(self, k):
         tag = self.r.exists(k)
