@@ -1,5 +1,6 @@
 from typing import Dict, Text, Any, NoReturn
 
+import demjson
 import jmespath
 import requests
 from jmespath.exceptions import JMESPathError
@@ -9,6 +10,7 @@ from rrtv_httprunner import exceptions
 from rrtv_httprunner.exceptions import ValidationFailure, ParamsError
 from rrtv_httprunner.models import VariablesMapping, Validators, FunctionsMapping
 from rrtv_httprunner.parser import parse_data, parse_string_value, get_mapping_function
+from rrtv_httprunner.utils import is_json
 
 
 def get_uniform_comparator(comparator: Text):
@@ -161,7 +163,23 @@ class ResponseObject(object):
             try:
                 value = self.resp_obj.json()
             except ValueError:
-                value = self.resp_obj.content
+                response_dict = {}
+                for attr in dir(self.resp_obj):
+                    if attr == "text":
+                        response_dict[attr] = getattr(self.resp_obj, attr)
+                response_body = {}
+                if "text" in response_dict and response_dict["text"] != "":
+                    if is_json(response_dict["text"]):
+                        response_dict['text'] = demjson.decode(response_dict['text'])
+                        for k, v in response_dict['text'].items():
+                            response_body[k] = v
+                        for k, v in response_body["data"].items():
+                            if isinstance(k, int):
+                                response_body["data"][str(k)] = response_body["data"].pop(k)
+                    else:
+                        response_body["data"] = response_dict['text']
+                value = response_body
+                # value = self.resp_obj.content
         elif key == "cookies":
             value = self.resp_obj.cookies.get_dict()
         else:
@@ -186,11 +204,6 @@ class ResponseObject(object):
             return None
         try:
             key_list = [key for key in resp_obj_meta.keys()]
-            # flag = False
-            # for k in key_list:
-            #     if not isinstance(expr, int):
-            #         if k in expr:
-            #             flag = True
             flag = any(k in expr for k in key_list if not isinstance(expr, int))
             check_value = jmespath.search(expr, resp_obj_meta) if flag is True else expr
         except JMESPathError as ex:
