@@ -4,7 +4,6 @@ import itertools
 import json
 import os.path
 import platform
-import re
 import uuid
 from multiprocessing import Queue
 from typing import Dict, List, Any, Text, NoReturn, Union
@@ -322,6 +321,78 @@ def execute_cmd(cmd: Text) -> NoReturn:
     os.system(parsed_string)
 
 
+# def execute_redis(rd: Union[Text, Dict, List], cli: Text) -> Any:
+#     def is_get():
+#         get_func = ["get(", "hget(", "hkeys(", "hash_get(", "str_get(", "hash_getall("]
+#         return any(parsed_string.lower().startswith(func) is True for func in get_func)
+#
+#     def is_del():
+#         del_func = ["del(", "hdel(", "delete(", "hash_del("]
+#         return any(parsed_string.lower().startswith(func) is True for func in del_func)
+#
+#     def is_exists():
+#         exists_func = ["exists("]
+#         return any(parsed_string.lower().startswith(func) is True for func in exists_func)
+#
+#     def execute(config, content):
+#         handler = RedisHandler(config)
+#         try:
+#             if parsed_string.lower().startswith("get("):
+#                 return handler.str_get(content[0])
+#             elif parsed_string.lower().startswith("hget("):
+#                 handler.hash_hkeys(content[0]) if len(content) == 1 else handler.hash_get(content[0], content[1])
+#             elif parsed_string.lower().startswith("hkeys("):
+#                 handler.hash_hkeys(content[0])
+#             elif parsed_string.lower().startswith("set("):
+#                 return handler.str_set(content[0], content[1])
+#             elif parsed_string.lower().startswith("hset("):
+#                 return handler.hash_set(content[0], content[1], content[2])
+#             elif parsed_string.lower().startswith("del("):
+#                 return handler.delete(content[0])
+#             elif parsed_string.lower().startswith("hdel("):
+#                 return handler.hash_del(content[0], content[1])
+#             elif parsed_string.lower().startswith("clean") and parsed_string != "clean_redis":
+#                 return handler.clean_redis
+#             else:
+#                 scope = {'handler': RedisHandler(config)}
+#                 cli = "handler." + parsed_string
+#                 return eval(cli, scope)
+#         except:
+#             raise Exception("检测传入key是否错误")
+#
+#     match_start_position = cli.index(":", 0)
+#     parsed_string = cli[match_start_position + 1:]
+#     logger.debug("execute redis: { " + parsed_string + " }")
+#     content = re.findall(r'\'(.*?)\'', str(parsed_string))
+#
+#     data_source = eval(rd) if isinstance(rd, Text) else rd
+#     if isinstance(data_source, List):
+#         for v in data_source:
+#             value = execute(v, content)
+#             if is_get() is True:
+#                 if value is not None:
+#                     return value
+#                 elif data_source.index(v) == len(data_source) - 1 and value is None:
+#                     return None
+#             if is_del() is True:
+#                 if value == 1:  # delete success
+#                     logger.debug(f"在{v}中删除成功")
+#                     return 1
+#                 elif data_source.index(v) == len(data_source) - 1 and value == 0:
+#                     return 0
+#             elif is_exists() is True:
+#                 if value == 1:
+#                     logger.debug(f"在{v}中存在key:{content}")
+#                     return value
+#                 elif data_source.index(v) == len(data_source) - 1 and value == 0:
+#                     return 0
+#             else:
+#                 return value
+#
+#     else:
+#         return execute(data_source, content)
+
+
 def execute_redis(rd: Union[Text, Dict, List], cli: Text) -> Any:
     def is_get():
         get_func = ["get(", "hget(", "hkeys(", "hash_get(", "str_get(", "hash_getall("]
@@ -335,41 +406,39 @@ def execute_redis(rd: Union[Text, Dict, List], cli: Text) -> Any:
         exists_func = ["exists("]
         return any(parsed_string.lower().startswith(func) is True for func in exists_func)
 
-    def execute(config, content):
-        handler = RedisHandler(config)
+    def execute(cli, scope):
         try:
-            if parsed_string.lower().startswith("get("):
-                return handler.str_get(content[0])
-            elif parsed_string.lower().startswith("hget("):
-                handler.hash_hkeys(content[0]) if len(content) == 1 else handler.hash_get(content[0], content[1])
-            elif parsed_string.lower().startswith("hkeys("):
-                handler.hash_hkeys(content[0])
-            elif parsed_string.lower().startswith("set("):
-                return handler.str_set(content[0], content[1])
-            elif parsed_string.lower().startswith("hset("):
-                return handler.hash_set(content[0], content[1], content[2])
-            elif parsed_string.lower().startswith("del("):
-                return handler.delete(content[0])
-            elif parsed_string.lower().startswith("hdel("):
-                return handler.hash_del(content[0], content[1])
-            elif parsed_string.lower().startswith("clean") and parsed_string != "clean_redis":
-                return handler.clean_redis
+            if cli.lower().startswith("get("):
+                new_cli = "handler.str_get" + cli.split("get", 1)[1]
+            elif cli.lower().startswith("hget("):
+                new_cli = "handler.hash_get" + cli.split("hget", 1)[1]
+            elif cli.lower().startswith("hkeys("):
+                new_cli = "handler.hash_hkeys" + cli.split("hkeys", 1)[1]
+            elif cli.lower().startswith("set("):
+                new_cli = "handler.str_set" + cli.split("set", 1)[1]
+            elif cli.lower().startswith("hset("):
+                new_cli = "handler.hash_set" + cli.split("hset", 1)[1]
+            elif cli.lower().startswith("del("):
+                new_cli = "handler.delete" + cli.split("del", 1)[1]
+            elif cli.lower().startswith("hdel("):
+                new_cli = "handler.hash_del" + cli.split("hdel", 1)[1]
+            elif cli.lower().startswith("clean") and cli != "clean_redis":
+                new_cli = "handler.clean_redis" + cli.split("clean", 1)[1]
             else:
-                scope = {'handler': RedisHandler(config)}
-                cli = "handler." + parsed_string
-                return eval(cli, scope)
+                new_cli = "handler." + cli
+            return eval(new_cli, scope)
         except:
             raise Exception("检测传入key是否错误")
 
     match_start_position = cli.index(":", 0)
     parsed_string = cli[match_start_position + 1:]
     logger.debug("execute redis: { " + parsed_string + " }")
-    content = re.findall(r'\'(.*?)\'', str(parsed_string))
-
+    cli = parsed_string
     data_source = eval(rd) if isinstance(rd, Text) else rd
     if isinstance(data_source, List):
-        for v in data_source:
-            value = execute(v, content)
+        for index, v in enumerate(data_source):
+            scope = {'handler': RedisHandler(v)}
+            value = execute(cli, scope)
             if is_get() is True:
                 if value is not None:
                     return value
@@ -383,15 +452,19 @@ def execute_redis(rd: Union[Text, Dict, List], cli: Text) -> Any:
                     return 0
             elif is_exists() is True:
                 if value == 1:
-                    logger.debug(f"在{v}中存在key:{content}")
+                    logger.debug(f"在{v}中存在key:{cli}")
                     return value
                 elif data_source.index(v) == len(data_source) - 1 and value == 0:
                     return 0
             else:
-                return value
+                if value is not None and index != len(data_source) - 1:
+                    return value
 
     else:
-        return execute(data_source, content)
+        scope = {'handler': RedisHandler(rd)}
+        return execute(cli, scope)
+
+    # return eval(cli, scope)
 
 
 def execute_mongo(db: Union[Text, Dict], operation: Text) -> Text:
@@ -485,7 +558,8 @@ def write_excel(content: Dict, target_dir):
         open = pd.read_excel(file, sheet_name=OPEN)
         ugc = pd.read_excel(file, sheet_name=WEB)
     except:
-        df = pd.DataFrame({"所属服务": [], "method": [], "url": [], "name": [], "界面位置": [], "90天是否有调用": [], "curl": []})  # 结构
+        df = pd.DataFrame(
+            {"所属服务": [], "method": [], "url": [], "name": [], "界面位置": [], "90天是否有调用": [], "curl": []})  # 结构
         writer = pd.ExcelWriter(file, engine="openpyxl")
         df.to_excel(writer, sheet_name=APP, index=False)
         df.to_excel(writer, sheet_name=FRIDAY, index=False)
@@ -500,7 +574,8 @@ def write_excel(content: Dict, target_dir):
 
     tier = get_testcases_tier(content["dir"])
     service = tier[2] if tier[0] == "gateway_api" else ""
-    add_data = [service.replace("_", "-"), content["method"], content["url"], content["name"], content["location"], content["call"],
+    add_data = [service.replace("_", "-"), content["method"], content["url"], content["name"], content["location"],
+                content["call"],
                 content["curl"]]
 
     with pd.ExcelWriter(file, mode='a', engine='openpyxl', if_sheet_exists='replace') as writer:
